[![Codecov](https://img.shields.io/codecov/c/github/ehmicky/clean-write.svg?label=tested&logo=codecov)](https://codecov.io/gh/ehmicky/clean-write)
[![Travis](https://img.shields.io/badge/cross-platform-4cc61e.svg?logo=travis)](https://travis-ci.org/ehmicky/clean-write)
[![Node](https://img.shields.io/node/v/clean-write.svg?logo=node.js)](https://www.npmjs.com/package/clean-write)
[![Gitter](https://img.shields.io/gitter/room/ehmicky/clean-write.svg?logo=gitter)](https://gitter.im/ehmicky/clean-write)
[![Twitter](https://img.shields.io/badge/%E2%80%8B-twitter-4cc61e.svg?logo=twitter)](https://twitter.com/intent/follow?screen_name=ehmicky)
[![Medium](https://img.shields.io/badge/%E2%80%8B-medium-4cc61e.svg?logo=medium)](https://medium.com/@ehmicky)

Cleanup corrupted files on write errors.

When an exception is thrown while a file is being written, that file will be
corrupted. The same problem occurs when the process exits unexpectedly (for
example with `CTRL-C`).

This library removes corrupted files in such cases.

# Example

<!-- Remove 'eslint-skip' once estree supports top-level await -->
<!-- eslint-skip -->

```js
const cleanWrite = require('clean-write')

const { writeFile } = require('fs')
const { promisify } = require('util')
const writeFileAsync = promisify(writeFile)

const filePath = './path/to/file.js'
const writeFunction = async function() {
  await writeFileAsync(filePath, 'example')
}

// If an exception happens or if the program exits, the file will be removed
await cleanWrite(writeFunction, filePath)
```

# Install

```bash
npm install clean-write
```

# Usage

## cleanWrite(writeFunction, filePath)

`writeFunction`: `() => Promise<void>`<br>`filePath`: `string`<br>_Returns_:
`Promise<void>`

The file is removed if either:

- `writeFunction()` throws an exception or returns a rejected `Promise`
- the process exits before `writeFunction()` completes

# Support

If you found a bug or would like a new feature, _don't hesitate_ to
[submit an issue on GitHub](../../issues).

For other questions, feel free to
[chat with us on Gitter](https://gitter.im/ehmicky/clean-write).

Everyone is welcome regardless of personal background. We enforce a
[Code of conduct](CODE_OF_CONDUCT.md) in order to promote a positive and
inclusive environment.

# Contributing

This project was made with ❤️. The simplest way to give back is by starring and
sharing it online.

If the documentation is unclear or has a typo, please click on the page's `Edit`
button (pencil icon) and suggest a correction.

If you would like to help us fix a bug or add a new feature, please check our
[guidelines](CONTRIBUTING.md). Pull requests are welcome!

<!-- Thanks go to our wonderful contributors: -->

<!-- ALL-CONTRIBUTORS-LIST:START -->
<!-- prettier-ignore -->
<table><tr><td align="center"><a href="https://twitter.com/ehmicky"><img src="https://avatars2.githubusercontent.com/u/8136211?v=4" width="100px;" alt="ehmicky"/><br /><sub><b>ehmicky</b></sub></a><br /><a href="https://github.com/ehmicky/clean-write/commits?author=ehmicky" title="Code">💻</a> <a href="#design-ehmicky" title="Design">🎨</a> <a href="#ideas-ehmicky" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/ehmicky/clean-write/commits?author=ehmicky" title="Documentation">📖</a></td></tr></table>

<!-- ALL-CONTRIBUTORS-LIST:END -->
